Struct Event

pub struct Event { /* private fields */ }
GPIO chip info event related definitions. Line status watch events

Accessors for the info event objects allowing to monitor changes in GPIO line state.

Callers can be notified about changes in line’s state using the interfaces exposed by GPIO chips. Each info event contains information about the event itself (timestamp, type) as well as a snapshot of line’s state in the form of a line-info object.

Implementations

Source

impl Event

pub fn event_type(&self) -> Result<InfoChangeKind>

Get the event type of the status change event.

pub fn timestamp(&self) -> Duration

Get the timestamp of the event, read from the monotonic clock.

pub fn line_info(&self) -> Result<&InfoRef>

Get the line-info object associated with the event.