Struct Chip

pub struct Chip { /* private fields */ }
GPIO chip

A GPIO chip object is associated with an open file descriptor to the GPIO character device. It exposes basic information about the chip and allows callers to retrieve information about each line, watch lines for state changes and make line requests.

Implementations

Source

impl Chip

pub fn open<P: AsRef<Path>>(path: &P) -> Result<Self>

Find a chip by path.

pub fn info(&self) -> Result<Info>

Get the chip name as represented in the kernel.

pub fn path(&self) -> Result<&str>

Get the path used to find the chip.

pub fn line_info(&self, offset: Offset) -> Result<Info>

Get a snapshot of information about the line.

pub fn watch_line_info(&self, offset: Offset) -> Result<Info>

Get the current snapshot of information about the line at given offset and start watching it for future changes.

pub fn unwatch(&self, offset: Offset)

Stop watching a line

pub fn wait_info_event(&self, timeout: Option<Duration>) -> Result<bool>

Wait for line status events on any of the watched lines on the chip.

pub fn read_info_event(&self) -> Result<Event>

Read a single line status change event from the chip. If no events are pending, this function will block.

pub fn line_offset_from_name(&self, name: &str) -> Result<Offset>

Map a GPIO line’s name to its offset within the chip.

pub fn request_lines( &self, rconfig: Option<&Config>, lconfig: &Config, ) -> Result<Request>

Request a set of lines for exclusive usage.