pub enum EventClock {
Monotonic,
Realtime,
HTE,
}Expand description
Event clock settings.
Variants
Monotonic
Line uses the monotonic clock for edge event timestamps.
Realtime
Line uses the realtime clock for edge event timestamps.
HTE
Line uses the hardware timestamp engine clock for edge event timestamps.