Struct Info

pub struct Info { /* private fields */ }
Line info

This is the owned counterpart to InfoRef. Due to a Deref implementation, all functions of InfoRef can also be called on this type.

Methods from Deref<Target = InfoRef>

pub fn try_clone(&self) -> Result<Info>

Clones the line info object.

pub fn offset(&self) -> Offset

Get the offset of the line within the GPIO chip.

The offset uniquely identifies the line on the chip. The combination of the chip and offset uniquely identifies the line within the system.

pub fn name(&self) -> Result<&str>

Get GPIO line’s name.

pub fn is_used(&self) -> bool

Returns True if the line is in use, false otherwise.

The user space can’t know exactly why a line is busy. It may have been requested by another process or hogged by the kernel. It only matters that the line is used and we can’t request it.

pub fn consumer(&self) -> Result<&str>

Get the GPIO line’s consumer name.

pub fn direction(&self) -> Result<Direction>

Get the GPIO line’s direction.

pub fn is_active_low(&self) -> bool

Returns true if the line is “active-low”, false otherwise.

pub fn bias(&self) -> Result<Option<Bias>>

Get the GPIO line’s bias setting.

pub fn drive(&self) -> Result<Drive>

Get the GPIO line’s drive setting.

pub fn edge_detection(&self) -> Result<Option<Edge>>

Get the current edge detection setting of the line.

pub fn event_clock(&self) -> Result<EventClock>

Get the current event clock setting used for edge event timestamps.

pub fn is_debounced(&self) -> bool

Returns true if the line is debounced (either by hardware or by the kernel software debouncer), false otherwise.

pub fn debounce_period(&self) -> Duration

Get the debounce period of the line.