Struct Settings

pub struct Settings { /* private fields */ }
Line settings objects.

Line settings object contains a set of line properties that can be used when requesting lines or reconfiguring an existing request.

Mutators in general can only fail if the new property value is invalid. The return values can be safely ignored - the object remains valid even after a mutator fails and simply uses the sane default appropriate for given property.

Implementations

Source

impl Settings

pub fn new() -> Result<Self>

Create a new line settings object.

pub fn reset(&mut self)

Resets the line settings object to its default values.

pub fn try_clone(&self) -> Result<Self>

Makes a copy of the settings object.

pub fn set_prop(&mut self, props: &[SettingVal]) -> Result<&mut Self>

Set line prop setting.

pub fn prop(&self, property: SettingKind) -> Result<SettingVal>

Get the line prop setting.

pub fn set_direction(&mut self, direction: Direction) -> Result<&mut Self>

Set the line direction.

pub fn direction(&self) -> Result<Direction>

Get the direction setting.

pub fn set_edge_detection(&mut self, edge: Option<Edge>) -> Result<&mut Self>

Set the edge event detection setting.

pub fn edge_detection(&self) -> Result<Option<Edge>>

Get the edge event detection setting.

pub fn set_bias(&mut self, bias: Option<Bias>) -> Result<&mut Self>

Set the bias setting.

pub fn bias(&self) -> Result<Option<Bias>>

Get the bias setting.

pub fn set_drive(&mut self, drive: Drive) -> Result<&mut Self>

Set the drive setting.

pub fn drive(&self) -> Result<Drive>

Get the drive setting.

pub fn set_active_low(&mut self, active_low: bool) -> &mut Self

Set active-low setting.

pub fn active_low(&self) -> bool

Check the active-low setting.

pub fn set_debounce_period(&mut self, period: Duration) -> &mut Self

Set the debounce period setting.

pub fn debounce_period(&self) -> Result<Duration>

Get the debounce period.

pub fn set_event_clock(&mut self, clock: EventClock) -> Result<&mut Self>

Set the event clock setting.

pub fn event_clock(&self) -> Result<EventClock>

Get the event clock setting.

pub fn set_output_value(&mut self, value: Value) -> Result<&mut Self>

Set the output value setting.

pub fn output_value(&self) -> Result<Value>

Get the output value, 0 or 1.