Struct Buffer

pub struct Buffer { /* private fields */ }
Line edge events buffer

Implementations

Source

impl Buffer

pub fn new(capacity: usize) -> Result<Self>

Create a new edge event buffer.

If capacity equals 0, it will be set to a default value of 64. If capacity is larger than 1024, it will be limited to 1024.

pub fn capacity(&self) -> usize

Get the capacity of the event buffer.

pub fn read_edge_events<'a>( &'a mut self, request: &Request, ) -> Result<Events<'a>>

Get edge events from a line request.

This function will block if no event was queued for the line.