Struct Config

pub struct Config { /* private fields */ }
Request configuration objects

Request config objects are used to pass a set of options to the kernel at the time of the line request. The mutators don’t return error values. If the values are invalid, in general they are silently adjusted to acceptable ranges.

Implementations

Source

impl Config

pub fn new() -> Result<Self>

Create a new request config object.

pub fn set_consumer(&mut self, consumer: &str) -> Result<&mut Self>

Set the consumer name for the request.

If the consumer string is too long, it will be truncated to the max accepted length.

pub fn consumer(&self) -> Result<&str>

Get the consumer name configured in the request config.

pub fn set_event_buffer_size(&mut self, size: usize) -> &mut Self

Set the size of the kernel event buffer for the request.

pub fn event_buffer_size(&self) -> usize

Get the edge event buffer size setting for the request config.