pub struct Event { /* private fields */ }Expand description
GPIO chip info event related definitions. Line status watch events
Accessors for the info event objects allowing to monitor changes in GPIO line state.
Callers can be notified about changes in line’s state using the interfaces exposed by GPIO chips. Each info event contains information about the event itself (timestamp, type) as well as a snapshot of line’s state in the form of a line-info object.
Implementations
Sourceimpl Event
impl Event
Sourcepub fn event_type(&self) -> Result<InfoChangeKind>
pub fn event_type(&self) -> Result<InfoChangeKind>
Get the event type of the status change event.