pub fn is_gpiochip_device<P: AsRef<Path>>(path: &P) -> bool
Check if the file pointed to by path is a GPIO chip character device.
Returns true if the file exists and is a GPIO chip character device or a symbolic link to it.