pub struct Event(/* private fields */);Expand description
Line edge events handling
An edge event object contains information about a single line edge event. It contains the event type, timestamp and the offset of the line on which the event occurred as well as two sequence numbers (global for all lines in the associated request and local for this line only).
Edge events are stored into an edge-event buffer object to improve performance and to limit the number of memory allocations when a large number of events are being read.
Implementations
Sourceimpl Event
impl Event
Sourcepub fn event_type(&self) -> Result<EdgeKind>
pub fn event_type(&self) -> Result<EdgeKind>
Get the event type.
Sourcepub fn line_offset(&self) -> Offset
pub fn line_offset(&self) -> Offset
Get the offset of the line on which the event was triggered.
Sourcepub fn global_seqno(&self) -> usize
pub fn global_seqno(&self) -> usize
Get the global sequence number of the event.
Returns sequence number of the event relative to all lines in the associated line request.
Sourcepub fn line_seqno(&self) -> usize
pub fn line_seqno(&self) -> usize
Get the event sequence number specific to concerned line.
Returns sequence number of the event relative to the line within the lifetime of the associated line request.